==> 0.0.6.tar.gz: example/lib/pages/conversion/component/addTextMsg.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:provider/provider.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';
import 'package:tencent_im_sdk_plugin_example/provider/currentMessageList.dart';

class TextMsg extends StatelessWidget {
  String toUser;
  int type;
  TextMsg(this.toUser, this.type);
  TextEditingController inputController = new TextEditingController();

  onSubmitted(String s, context) async {
    if (s == '' || s == null) {
      return;
    }
    V2TimValueCallback<V2TimMessage> sendRes;
    if (type == 1) {
      sendRes = await tencent_im_sdk_plugin.v2TIMManager
          .sendC2CTextMessage(text: s, userID: toUser);
    } else {
      sendRes = await tencent_im_sdk_plugin.v2TIMManager
          .sendGroupTextMessage(text: s, groupID: toUser, priority: 1);
    }
    if (sendRes.code == 0) {
      List<V2TimMessage> list =
          Provider.of<CurrentMessageListModel>(context, listen: false).msgList;
      if (list == null) {
        list = new List();
      }
      list.add(sendRes.data);
      Provider.of<CurrentMessageListModel>(context, listen: false)
          .setCurrentMessageList(list);
      print('发送成功');
      inputController.clear();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: PhysicalModel(
        color: Colors.transparent,
        borderRadius: BorderRadius.circular(4),
        clipBehavior: Clip.antiAlias,
        child: Container(
          height: 34,
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(4),
            color: Colors.white,
          ),
          child: TextField(
            controller: inputController,
            onSubmitted: (s) {
              onSubmitted(s, context);
            },
            cursorColor: CommonColors.getThemeColor(),
            decoration: InputDecoration(
              border: InputBorder.none,
            ),
          ),
        ),
      ),
    );
  }
}

==> 0.0.10.tar.gz: example/lib/pages/conversion/component/addTextMsg.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:provider/provider.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_message.dart';
import 'package:tencent_im_sdk_plugin/models/v2_tim_value_callback.dart';
import 'package:tencent_im_sdk_plugin/tencent_im_sdk_plugin.dart';
import 'package:tencent_im_sdk_plugin_example/common/colors.dart';
import 'package:tencent_im_sdk_plugin_example/provider/currentMessageList.dart';

class TextMsg extends StatelessWidget {
  String toUser;
  int type;
  TextMsg(this.toUser, this.type);
  TextEditingController inputController = new TextEditingController();

  onSubmitted(String s, context) async {
    if (s == '' || s == null) {
      return;
    }
    V2TimValueCallback<V2TimMessage> sendRes;
    if (type == 1) {
      sendRes = await tencent_im_sdk_plugin.v2TIMManager
          .sendC2CTextMessage(text: s, userID: toUser);
    } else {
      sendRes = await tencent_im_sdk_plugin.v2TIMManager
          .sendGroupTextMessage(text: s, groupID: toUser, priority: 1);
    }

    if (sendRes.code == 0) {
      String key = (type == 1 ? "c2c_${toUser}" : "group_${toUser}");
      List<V2TimMessage> list = new List();
      list.add(sendRes.data);
      Provider.of<CurrentMessageListModel>(context, listen: false)
          .addMessage(key, list);
      print('发送成功');
      inputController.clear();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: PhysicalModel(
        color: Colors.transparent,
        borderRadius: BorderRadius.circular(4),
        clipBehavior: Clip.antiAlias,
        child: Container(
          height: 34,
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(4),
            color: Colors.white,
          ),
          child: TextField(
            controller: inputController,
            onSubmitted: (s) {
              onSubmitted(s, context);
            },
            cursorColor: CommonColors.getThemeColor(),
            decoration: InputDecoration(
              border: InputBorder.none,
            ),
          ),
        ),
      ),
    );
  }
}
